@@ -3,7 +3,12 @@
 
 DJabberd::Component::External - Interface to external plugins implementing JEP-0114
 
-=head1 DESCRIPTION
+=head1 SYNOPSIS
+
+  <Plugin DJabberd::Component::External>
+    ListenPort 23534
+    Secret somesecret
+  </Plugin>
 
 This component provides support for connecting external components that support the
 Jabber Component Protocol specified in JEP-0114. Specify the TCP port that the external component
@@ -20,13 +25,6 @@ Please note that this component only implements the "accept" variation of the pr
 where DJabberd opens a listen socket and waits for the component to connect. The "connect"
 variation, where the component waits for DJabberd to connect to it, is not supported.
 
-=head1 SYNOPSIS
-
-  <Plugin DJabberd::Component::External>
-    ListenPort 23534
-    Secret somesecret
-  </Plugin>
-
 =head1 LICENCE
 
 Copyright 2006 Martin Atkins and Six Apart
@@ -42,7 +40,7 @@ use base 'DJabberd::Component';
 use strict;
 use DJabberd::Log;
 use DJabberd::Util qw(exml);
-use DJabberd::Connection::ComponentIn;
+use DJabberd::Component::External::Connection;
 use IO::Socket::UNIX;
 use IO::Socket::INET;
 use Socket qw(IPPROTO_TCP TCP_NODELAY SOL_SOCKET SOCK_STREAM);
@@ -52,7 +50,7 @@ our $logger = DJabberd::Log->get_logger();
 sub set_config_listenport {
     my ($self, $port) = @_;
     
-    return $self->set_config_listenaddr($port);
+    $self->{listenport} = $port;
 }
 
 sub set_config_secret {
@@ -64,14 +62,20 @@ sub set_config_secret {
 sub set_config_listenaddr {
     my ($self, $addr) = @_;
     
-    $self->{listenaddr} = DJabberd::Util::as_bind_addr($addr);
+    $self->{listenaddr} = $addr;
 }
 
 sub finalize {
     my ($self) = @_;
     
-    $logger->logdie("No ListenPort specified for external component") unless $self->{listenaddr};
-    $self->{listenaddr} = "127.0.0.1:".$self->{listenaddr} if $self->{listenaddr} =~ /^\d+$/;
+    # If the address starts with a slash, it's a unix domain socket
+    if ($self->{listenaddr} =~ m!^/!) {
+        $logger->logdie("Can't specify ListenPort for external component on a UNIX domain socket") if $self->{listenport};
+    }
+    else {
+        $logger->logdie("No ListenPort specified for external component") unless $self->{listenport};
+        $self->{listenaddr} ||= "127.0.0.1";
+    }
 
     $logger->logdie("No Secret specified for external component") unless $self->{secret};
     
@@ -151,16 +155,18 @@ sub _start_listener {
         $logger->logdie("Error creating UNIX domain socket $bindaddr: $@") unless $server;
         $logger->info("Started listener for component ".$self->domain." on UNIX domain socket $bindaddr");
     } else {
+        my $localaddr = $bindaddr.":".$self->{listenport};
+
         $server = IO::Socket::INET->new(
-            LocalAddr => $bindaddr,
+            LocalAddr => $localaddr,
             Type      => SOCK_STREAM,
             Proto     => IPPROTO_TCP,
             Blocking  => 0,
             Reuse     => 1,
             Listen    => 10
         );
-        $logger->logdie("Error creating listen socket for <$bindaddr>: $@") unless $server;
-        $logger->info("Started listener for component ".$self->domain." on TCP socket <$bindaddr>");
+        $logger->logdie("Error creating listen socket for <$localaddr>: $@") unless $server;
+        $logger->info("Started listener for component ".$self->domain." on TCP socket <$localaddr>");
     }
 
     # Brad thinks this is necessary under Perl 5.6, and who am I to argue?
@@ -179,7 +185,7 @@ sub _start_listener {
             setsockopt($csock, IPPROTO_TCP, TCP_NODELAY, pack("l", 1)) or $logger->logdie("Couldn't set TCP_NODELAY");
         }
 
-        my $connection = DJabberd::Connection::ComponentIn->new($csock, $vhost->server, $self);
+        my $connection = DJabberd::Component::External::Connection->new($csock, $vhost->server, $self);
         $connection->watch_read(1);
         $self->{connection} = $connection;
 
