@@ -2,7 +2,6 @@ package DJabberd::Connection;
 use strict;
 use warnings;
 use base 'Danga::Socket';
-use bytes;
 use fields (
             'saxhandler',
             'parser',
@@ -13,7 +12,6 @@ use fields (
             'server',         # our DJabberd server object, which we used to find the VHost
             'ssl',            # undef when not in ssl mode, else the $ssl object from Net::SSLeay
             'stream_id',      # undef until set first time
-            'to_host',        # undef until stream start
             'version',        # the DJabberd::StreamVersion we negotiated
             'rcvd_features',  # the features stanza we've received from the other party
             'log',            # Log::Log4perl object for this connection
@@ -24,9 +22,6 @@ use fields (
             'iqctr',          # iq counter.  incremented whenever we SEND an iq to the party (roster pushes, etc)
             'in_stream',      # bool:  true if we're in a stream tag
             'counted_close',  # bool:  temporary here to track down the overcounting of disconnects
-            'disconnect_handlers',  # array of coderefs to call when this connection is closed for any reason
-
-            'ssl_empty_read_ct', # int: number of consecutive empty SSL reads.
             );
 
 our $connection_id = 1;
@@ -50,25 +45,15 @@ our $hook_logger = DJabberd::Log->get_logger("DJabberd::Hook");
 use constant POLLIN        => 1;
 use constant POLLOUT       => 4;
 
-BEGIN {
-    my $xmldebug = $ENV{XMLDEBUG};
-
-    if ($xmldebug) {
-        eval 'use constant XMLDEBUG => "' . quotemeta($xmldebug) . '"';
-        die "XMLDEBUG path '$xmldebug' needs to be a directory writable by the user you are running $0 as\n" unless -w $xmldebug;
-    } else {
-        eval "use constant XMLDEBUG => ''";
-    }
-}
-
+use constant XMLDEBUG      => "/tmp/djabberd/";
 our %LOGMAP;
 
 sub new {
     my ($class, $sock, $server) = @_;
     my $self = $class->SUPER::new($sock);
 
-    croak("Server param not a DJabberd (server) object, '" . ref($server) . "'")
-        unless $server->isa("DJabberd");
+    croak("Server param not a DJabberd (server) object, actually a '$server'")
+        unless ref $server eq "DJabberd";
 
     $self->{vhost}   = undef;  # set once we get a stream start header from them.
     $self->{server}  = $server;
@@ -92,7 +77,7 @@ sub new {
     }
 
     if (XMLDEBUG) {
-        system("mkdir -p " . XMLDEBUG ."/$$/");
+        system("mkdir -p " . XMLDEBUG ."$$/");
         my $handle = IO::Handle->new;
         no warnings;
         my $from = $fromip || "outbound";
@@ -139,13 +124,11 @@ sub new_iq_id {
 
 sub log_outgoing_data {
     my ($self, $text) = @_;
-    my $id = $self->{id} ||= 'no_id';
-    
     if($self->xmllog->is_debug) {
-        $self->xmllog->debug("$id > " . $text);
+        $self->xmllog->debug("$self->{id} > " . $text);
     } else {
         local $DJabberd::ASXML_NO_TEXT = 1;
-        $self->xmllog->info("$id > " . $text);
+        $self->xmllog->info("$self->{id} > " . $text);
     }
 }
 
@@ -253,17 +236,6 @@ sub set_bound_jid {
     $self->{bound_jid} = $jid;
 }
 
-sub set_to_host {
-    my ($self, $host) = @_;
-    $self->{to_host} = $host;
-}
-
-sub to_host {
-    my $self = shift;
-    return $self->{to_host} or
-        die "To host accessed before it was set";
-}
-
 sub set_version {
     my ($self, $verob) = @_;
     $self->{version} = $verob;
@@ -499,17 +471,7 @@ sub event_read {
 
         # Net::SSLeays buffers internally, so if we didn't read anything, it's
         # in its buffer
-        unless ($data && length $data) {
-            # a few of these in a row implies an EOF.  else it could
-            # just be the underlying socket was readable, but there
-            # wasn't enough of an SSL packet for OpenSSL/etc to return
-            # any unencrypted data back to us.
-            if (++$self->{'ssl_empty_read_ct'} >= 10) {
-                $self->close('ssl_eof');
-            }
-            return;
-        }
-        $self->{'ssl_empty_read_ct'} = 0;
+        return unless $data && length $data;
         $bref = \$data;
     } else {
         # non-ssl mode:
@@ -580,7 +542,6 @@ sub start_init_stream {
     my %opts = @_;
     my $extra_attr = delete $opts{'extra_attr'} || "";
     my $to         = delete $opts{'to'} || Carp::croak("need 'to' domain");
-    my $xmlns      = delete $opts{'xmlns'} || "jabber:server";
     die if %opts;
 
     # {=init-version-is-max} -- we must announce the highest version we support
@@ -593,7 +554,7 @@ sub start_init_stream {
     $to = "" if $DJabberd::_T_NO_TO_IN_DIALBACKVERIFY_STREAM;
 
     # {=xml-lang}
-    my $xml = qq{<?xml version="1.0" encoding="UTF-8"?><stream:stream $to xmlns:stream='http://etherx.jabber.org/streams' xmlns='}.exml($xmlns).qq{' xml:lang='en' $extra_attr $ver_attr>};
+    my $xml = qq{<?xml version="1.0" encoding="UTF-8"?><stream:stream $to xmlns:stream='http://etherx.jabber.org/streams' xmlns='jabber:server' xml:lang='en' $extra_attr $ver_attr>};
     $self->log_outgoing_data($xml);
     $self->write($xml);
 }
@@ -606,7 +567,6 @@ sub start_stream_back {
 
     # bind us to a vhost now.
     my $to_host     = $ss->to;
-    $self->set_to_host($to_host) if $to_host;
 
     # Spec rfc3920 (dialback section) says: Note: The 'to' and 'from'
     # attributes are OPTIONAL on the root stream element.  (during
@@ -744,25 +704,6 @@ sub close_stream {
     $self->write(sub { $self->close; });
 }
 
-sub add_disconnect_handler {
-    my ($self, $callback) = @_;
-    $self->{disconnect_handlers} ||= [];
-    push @{$self->{disconnect_handlers}}, $callback;
-}
-
-sub _run_callback_list {
-    my ($self, $listref, @args) = @_;
-    
-    return unless ref $listref eq 'ARRAY';
-    
-    foreach my $callback (@$listref) {
-        next unless ref $callback eq 'CODE';
-        
-        $callback->($self, @args);
-    }
-    
-}
-
 sub close {
     my DJabberd::Connection $self = shift;
     return if $self->{closed};
@@ -775,10 +716,8 @@ sub close {
     }
 
     $self->log->debug("DISCONNECT: $self->{id}\n") if $self->{id};
-    $self->_run_callback_list($self->{disconnect_handlers});
 
     if (my $ssl = $self->{ssl}) {
-        $self->set_writer_func(sub { return 0 });
         Net::SSLeay::free($ssl);
         $self->{ssl} = undef;
     }
@@ -799,7 +738,6 @@ sub close {
         delete $LOGMAP{$self};
     }
     $self->SUPER::close;
-
 }
 
 # DJabberd::Connection
